==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/osc/OSC_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Konfigurace OSC Pluginu</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Vstupní port</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Výstupní adresa</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Výstupní port</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="80"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="86"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>Invalid IP</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="168"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1  není platná IP adresa.
Prosím opravte zadání před potvrzením.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="85"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Tento plugin přidává vstupy pro zařízení podporující přenosový OSC protokol.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="136"/>
        <location filename="oscplugin.cpp" line="270"/>
        <source>Status: Not open</source>
        <translation>Stav: Není otevřen</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="139"/>
        <location filename="oscplugin.cpp" line="273"/>
        <source>Status: Open</source>
        <translation>Stav: Otevřen</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="141"/>
        <source>Packets sent: </source>
        <translation>Poslaných paketů:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="275"/>
        <source>Packets received: </source>
        <translation>Přijatých paketů:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="132"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="266"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/osc/OSC_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Konfigurace OSC Pluginu</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Vstupní port</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Výstupní adresa</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Výstupní port</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="88"/>
        <source>Channel number calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="96"/>
        <source>OSC path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="106"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="83"/>
        <source>Inputs</source>
        <translation>Vstupy</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="89"/>
        <source>Outputs</source>
        <translation>Výstupy</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>Invalid IP</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="171"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1  není platná IP adresa.
Prosím opravte zadání před potvrzením.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="91"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Tento plugin přidává vstupy pro zařízení podporující přenosový OSC protokol.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="142"/>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Status: Not open</source>
        <translation>Stav: Není otevřen</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="145"/>
        <location filename="oscplugin.cpp" line="279"/>
        <source>Status: Open</source>
        <translation>Stav: Otevřen</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <source>Packets sent: </source>
        <translation>Poslaných paketů:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="281"/>
        <source>Packets received: </source>
        <translation>Přijatých paketů:</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="138"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="272"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
</context>
</TS>
